TCT.TCT — Translator Component Toolkit 0.1 documentation

# TCT.TCT

Functions

`Gene_id_converter`(id_list, API_url) |
`ID_convert_to_preferred_name_nodeNormalizer`(id_list) |
`TCT_help`(func) |
`TRAPI_json_validation`(query_json_cur_clean, ...) |
`add_new_API_for_query`(APInames, metaKG, ...) | This function is used to add a new API beyond the current list of APIs for query Example: APInames, metaKG = add_new_API_for_query(APInames, metaKG, "BigGIM_BMG", "http://127.0.0.1:8000/find_path_by_predicate", "Gene-physically_interacts_with-gene", "Gene", "Gene")
`ask_chatGPT`(prompt_text) |
`ask_chatGPT4`(prompt_text) |
`connecting_two_dots_two_hops`(sorted_dic1, ...) |
`extract_json`(txt) |
`filter_APIs`(sele_predicates, metaKG) |
`find_link`(name) |
`find_path_by_two_ends`(subject1_ids, ...) |
`find_similar_category`(query_json_cur_clean, ...) |
`find_similar_predicates`(...) |
`format_id`(query_json_cur_clean) |
`format_query_json`(subject_ids, object_ids, ...) | Example input: subject_ids = ["NCBIGene:3845"] object_ids = [] subject_categories = ["biolink:Gene"] object_categories = ["biolink:Gene"] predicates = ["biolink:positively_correlated_with", "biolink:physically_interacts_with"]
`format_query_json_old`(subject_ids, ...) | Example input: subject_ids = ["NCBIGene:3845"] object_ids = [] subject_categories = ["biolink:Gene"] object_categories = ["biolink:Gene"] predicates = ["biolink:positively_correlated_with", "biolink:physically_interacts_with"]
`get_KP_metadata`() |
`get_SmartAPI_Translator_KP_info`() | Get the SmartAPI Translator KP info from the smart-api.info API.
`get_Translator_API_URL`(API_sele, APInames) |
`get_Translator_APIs`() |
`get_curie`(name) |
`get_pair_annotation`(result, input_node_list) |
`get_ranking_by_infores`(sorted_dic, ...) |
`get_ranking_by_kp`(sorted_dic, ...) |
`get_ranking_by_predicates`(sorted_dic, ...) |
`get_similar_category`(query_json_cur_clean, ...) |
`get_similar_predicate`(query_json_cur_clean, ...) |
`list_Translator_APIs`() |
`list_functions`() |
`load_json_template`() |
`merge_by_ranking_index`(...[, top_n, ...]) |
`merge_ranking_by_number_of_infores`(...[, ...]) |
`parallel_api_query`(URLS, query_json[, ...]) |
`parse_KG`(result) | subject_object subject object predicate primary_knowledge_sources aggregator_knowledge_sources subject_predicate_object_primary_knowledge_sources_aggregator_knowledge_sources
`parse_network_result`(result, input_node1_list) |
`parse_pair_annotation`(pairs_found, ...) |
`parse_result_old`(API_keys_sele, ...) |
`plot_graph_by_API`(for_plot) |
`plot_graph_by_infores`(for_plot) |
`plot_graph_by_predicates`(for_plot) |
`plot_heatmap`(predicates_by_nodes_df[, ...]) |
`plot_heatmap_ui`(predicates_by_nodes_df[, ...]) |
`plot_path_bar`(x, y[, fontsize, ...]) |
`query_KP`(remoteURL, query_json) |
`query_KP_all`(subject_ids, object_ids, ...) |
`query_chatGPT`(customized_input[, model]) |
`query_chatGPT4`(customized_input) |
`rank_by_primary_infores`(result_parsed, ...) | Editd Dec 5, 2023
`rank_by_primary_infores_input_as_list`(...) | Editd Dec 5, 2023
`ranking_result_by_predicates_object`(...) |
`ranking_result_by_predicates_subject`(...) |
`select_API`(sub_list, obj_list, metaKG) | sub_list = ["biolink:Gene", "biolink:Protein"] obj_list = ["biolink:Gene", "biolink:Disease"]
`select_concept`(sub_list, obj_list, metaKG) |
`select_predicates_inKP`(sub_list, obj_list, ...) | sub_list = ["biolink:Gene", "biolink:Protein"] obj_list = ["biolink:Gene", "biolink:Disease"] KPname = "" # it should be one of the names in APInames
`select_result_to_analysis`(sele_genes, ...) |
`visulization_one_hop_ranking`(...[, ...]) |
`visulization_one_hop_ranking_input_as_list`(...) |
`visulize_path`(input_node1_id, ...) |